@@ -298,7 +298,7 @@ echo "jupyterhub-singleuser ended gracefully"
                 instance_type = group_record['ec2_instance_type']
 
                 mem = group_record['mem']
-                cpu = group_record['cpu']
+                cpu = group_record['vcpu']
                 profile['profile_options']['instance_types']['choices'][sinfo_name] = dict(
                     display_name=f'{instance_type} - {cpu} CPU, {mem} GB',
                     pclusterslurmspawner_override=group_record,
@@ -317,7 +317,7 @@ echo "jupyterhub-singleuser ended gracefully"
 
         return table.to_html(table_id="slurm_spawner_table",
                              classes='table  table-bordered display dataTable',
-                             columns=['sinfo_name', 'queue', 'constraint', 'ec2_instance_type', 'mem', 'cpu',
+                             columns=['sinfo_name', 'queue', 'constraint', 'ec2_instance_type', 'mem', 'vcpu',
                                       'gpus'], index=False)
 
     def _options_form_default(self):
@@ -333,7 +333,7 @@ echo "jupyterhub-singleuser ended gracefully"
             first_row: SinfoRow = table.iloc[0]
 
             defaults = {
-                'req_nprocs': str(first_row.cpu),
+                'req_nprocs': str(first_row.vcpu),
                 'req_memory': str(first_row.mem),
                 'req_runtime': "01:00:00",
                 'req_partition': first_row.queue,
@@ -404,7 +404,7 @@ echo "jupyterhub-singleuser ended gracefully"
 
             submission_data[key] = form_value[0]
 
-        submission_data['req_nprocs'] = str(record['cpu'])
+        submission_data['req_nprocs'] = str(record['vcpu'])
         submission_data['req_memory'] = str(record['mem'])
         submission_data['req_partition'] = record['queue']
         submission_data['req_constraint'] = record['constraint']
